@@ -277,7 +277,7 @@ class ArcDiagram(BaseArcDiagram, Graph):
 
     Parameters
     ----------
-    graph: various formats
+    graph : various formats
         Graph object to plot. Various input formats are supported.
         In order of precedence:
 
@@ -290,7 +290,7 @@ class ArcDiagram(BaseArcDiagram, Graph):
 
           .. note:: If V <= 3, any (2, 2) or (3, 3) matrices will be interpreted as edge lists.
 
-        - networkx.Graph or igraph.Graph object
+        - networkx.Graph, igraph.Graph, or graph_tool.Graph object
 
     node_order : list or None, default None
         The ordering of nodes (left-to-right).
@@ -526,7 +526,7 @@ class InteractiveArcDiagram(DraggableArcDiagram, EmphasizeOnHoverGraph, Annotate
 
     Parameters
     ----------
-    graph: various formats
+    graph : various formats
         Graph object to plot. Various input formats are supported.
         In order of precedence:
 
@@ -539,7 +539,7 @@ class InteractiveArcDiagram(DraggableArcDiagram, EmphasizeOnHoverGraph, Annotate
 
           .. note:: If V <= 3, any (2, 2) or (3, 3) matrices will be interpreted as edge lists.
 
-        - networkx.Graph or igraph.Graph object
+        - networkx.Graph, igraph.Graph, or graph_tool.Graph object
 
     node_order : list or None, default None
         The ordering of nodes (left-to-right).
@@ -776,6 +776,7 @@ class InteractiveArcDiagram(DraggableArcDiagram, EmphasizeOnHoverGraph, Annotate
         keys = list(self.node_artists.keys()) + list(self.edge_artists.keys())
         self.artist_to_key = dict(zip(artists, keys))
         EmphasizeOnHover.__init__(self, artists)
+        self.mouseover_highlight_mapping = self._get_default_mouseover_highlight_mapping()
 
         artist_to_annotation = dict()
         if 'annotations' in kwargs:
